@@ -624,7 +624,7 @@ typedef struct nghttp3_buf {
    */
   uint8_t *end;
   /**
-   * :member:`pos` pointers to the start of data.  Typically, this
+   * :member:`pos` points to the start of data.  Typically, this
    * points to the address that next data should be read.  Initially,
    * it points to :member:`begin`.
    */
@@ -2198,6 +2198,9 @@ NGHTTP3_EXTERN int nghttp3_conn_add_write_offset(nghttp3_conn *conn,
  * If a stream denoted by |stream_id| is not found, this function
  * returns 0.
  *
+ * Alternatively, `nghttp3_conn_update_ack_offset` can be used to
+ * accomplish the same thing.
+ *
  * This function returns 0 if it succeeds, or one of the following
  * negative error codes:
  *
@@ -2207,6 +2210,31 @@ NGHTTP3_EXTERN int nghttp3_conn_add_write_offset(nghttp3_conn *conn,
 NGHTTP3_EXTERN int nghttp3_conn_add_ack_offset(nghttp3_conn *conn,
                                                int64_t stream_id, uint64_t n);
 
+/**
+ * @function
+ *
+ * `nghttp3_conn_update_ack_offset` tells |conn| that QUIC stack has
+ * acknowledged the stream data up to |offset| for a stream denoted by
+ * |stream_id|.
+ *
+ * If a stream denoted by |stream_id| is not found, this function
+ * returns 0.
+ *
+ * Alternatively, `nghttp3_conn_add_ack_offset` can be used to
+ * accomplish the same thing.
+ *
+ * This function returns 0 if it succeeds, or one of the following
+ * negative error codes:
+ *
+ * :macro:`NGHTTP3_ERR_INVALID_ARGUMENT`
+ *     |offset| is less than the number of bytes acknowledged so far.
+ * :macro:`NGHTTP3_ERR_CALLBACK_FAILURE`
+ *     User callback failed.
+ */
+NGHTTP3_EXTERN int nghttp3_conn_update_ack_offset(nghttp3_conn *conn,
+                                                  int64_t stream_id,
+                                                  uint64_t offset);
+
 /**
  * @function
  *
@@ -2278,6 +2306,9 @@ NGHTTP3_EXTERN void nghttp3_conn_shutdown_stream_write(nghttp3_conn *conn,
  * stream, this function returns 0.  If the stream has already
  * shutdown read-side stream, this function returns 0.
  *
+ * This function does not fail if a stream denoted by |stream_id| is
+ * not found, although it may fail with the other reasons.
+ *
  * This function returns 0 if it succeeds, or one of the following
  * negative error codes:
  *
@@ -2758,6 +2789,29 @@ NGHTTP3_EXTERN int nghttp3_check_header_value(const uint8_t *value, size_t len);
  */
 NGHTTP3_EXTERN int nghttp3_conn_is_drained(nghttp3_conn *conn);
 
+/**
+ * @function
+ *
+ * `nghttp3_pri_parse_priority` parses Priority header field value
+ * pointed by |value| of length |len|, and stores the result in the
+ * object pointed by |dest|.  Priority header field is defined in
+ * :rfc:`9218`.
+ *
+ * This function does not initialize the object pointed by |dest|
+ * before storing the result.  It only assigns the values that the
+ * parser correctly extracted to fields.
+ *
+ * This function returns 0 if it succeeds, or one of the following
+ * negative error codes:
+ *
+ * :macro:`NGHTTP3_ERR_INVALID_ARGUMENT`
+ *     Failed to parse the header field value.
+ */
+NGHTTP3_EXTERN int nghttp3_pri_parse_priority_versioned(int pri_version,
+                                                        nghttp3_pri *dest,
+                                                        const uint8_t *value,
+                                                        size_t len);
+
 /**
  * @macrosection
  *
@@ -2869,6 +2923,15 @@ NGHTTP3_EXTERN int nghttp3_err_is_fatal(int liberr);
   nghttp3_conn_get_stream_priority_versioned((CONN), NGHTTP3_PRI_VERSION,      \
                                              (DEST), (STREAM_ID))
 
+/*
+ * `nghttp3_pri_parse_priority` is a wrapper around
+ * `nghttp3_pri_parse_priority_versioned` to set the correct struct
+ * version.
+ */
+#define nghttp3_pri_parse_priority(DEST, VALUE, LEN)                           \
+  nghttp3_pri_parse_priority_versioned(NGHTTP3_PRI_VERSION, (DEST), (VALUE),   \
+                                       (LEN))
+
 #ifdef __cplusplus
 }
 #endif
